==> campsite-2.4.1.tbz: campsite/www-common/html/priv/lang/sh/templates.php <==
<?php
regGS("The template $1 is in use and can not be deleted.", "Šablon $1 je u upotrebi i ne može biti obrisan.");
regGS("The folder could not be deleted.", "Folder ne može biti izbrisan");
regGS("The directory must be empty", "Direktorijum mora biti prazan");
regGS("Create new folder", "Napravi novi folder");
regGS("Upload template", "Aplouduj šablon");
regGS("Creating new folder", "Pravljenje novog foldera");
regGS("You do not have the right to create new folders.", "Nemate pravo da pravite nove foldere");
regGS("The folder $1 could not be created", "Folder $1 ne može biti napravljen");
regGS("A file or folder having the name $1 already exists", "Fajl ili folder sa imenom $1 već postoji");
regGS("You do not have the right to delete templates.", "Nemate pravo da brišete šablone");
regGS("Are you sure you want to delete the folder $1 from $2?", "Da li ste sigurni da želite da obrišete folder $1 iz $2?");
regGS("Are you sure you want to delete the template $1 from folder $2?", "Da li ste sigurni da želite da obrišete šablon $1 iz foldera $2?");
regGS("Deleting template", "Brisanje šablona");
regGS("Deleting folder", "Brisanje foldera");
regGS("Template $1 was deleted", "Šablon $1 je obrisan");
regGS("Delete folder", "Obriši folder");
regGS("Folders", "Folderi");
regGS("No folders.", "Nema foldera.");
regGS("Files", "Fajlovi");
regGS("No templates.", "Nema šablona.");
regGS("Uploading template", "Aploudovanje šablona");
regGS("File", "Fajl");
regGS("Create new template", "Napravi novi šablon");
regGS("Creating new template", "Pravljenje novog šablona");
regGS("Duplicate template", "Dupliraj šablon");
regGS("Edit template", "Uredi šablon");
regGS("The template $1 has been created.", "Šablon $1 je napravljen.");
regGS("Do you want to edit the template ?", "Želite li da uredite šablon?");
regGS("The template $1 could not be created.", "Šablon $1 ne može biti napravljen.");
regGS("Template $1 was changed", "Šablon $1 je promenjen");
regGS("New template $1 was created", "Novi šablon $1 je napravljen");
regGS("Template $1 was duplicated into $2", "Šablon $1 je dupliran u $2");
regGS("Template charset", "Kodni raspored šablona");
regGS("Select a language/character set", "Izaberi jezik/kodni raspored");
regGS("All languages", "Svi jezici");
regGS("You do not have the right to modify templates.", "Nemate pravo da menjate šablone.");
regGS("Invalid template file $1", "Pogrešno ime šablona $1");
regGS("You do not have the right to create folders.", "Nemate pravo da pravite foldere.");
regGS("You do not have the right to upload templates.", "Nemate pravo da aploudujete šablone.");
regGS("You do not have the right to create templates.", "Nemate pravo da pravite šablone.");
regGS("Duplicate file", "Dupliraj fajl");
regGS("Delete file", "Obriši fajl");
regGS("Unable to save the template '$1' to the path '$2'.", "Šablon '$1' ne može biti snimljen na putanju '$2'.");
regGS("Please check if the user '$1' has permission to write in this directory.", "Proverite da li korisnik '$1' ima ovlašćenja da upisuje u ovoaj direktorijum.");
regGS("Unable to delete the template '$1' in the path '$2'.", "Šablon  '$1' ne može biti obrisan sa putanje '$2'.");
regGS("The folder has been deleted.", "Folder je izbrisan");
regGS("The template has been deleted.", "Šablon je izbrisan");
regGS("The template could not be deleted.", "Šablon ne može biti izbrisan");
regGS("Save", "Snimi");
?>

==> campsite-2.6.1.tbz: campsite/www-common/html/priv/lang/sh/templates.php <==
<?php 
regGS("Template ID:", "");
regGS("Template ID", "");
regGS("Template $1 no longer exists!", "");
regGS("New template $1 created", "");
regGS("If the file you specified is a text file, you can convert its character set using the dropdown below.", "");
regGS("Directory $1 was deleted", "");
regGS("Directory $1 created.", "");
regGS("You must select a file to upload.", "");
regGS("You can only replace a file with a file of the same type.  The original file is of type \"$1\", and the file you uploaded was of type \"$2\".", "");
regGS("Unable to save the file '$1' to the path '$2'.", "");
regGS("Replace file:", "");
regGS("Replace", "");
regGS("File \"$1\" uploaded.", "");
regGS("File \"$1\" replaced.", "");
regGS("The folder name can't be '..' or '.'", "");
regGS("The template '$1' was saved successfully.", "Šablon '$1' je uspešno snimljen.");
regGS("The template $1 is in use and can not be deleted.", "Šablon $1 je u upotrebi i ne može biti obrisan.");
regGS("Create new folder", "Napravi novi folder");
regGS("Upload template", "Aplouduj šablon");
regGS("You do not have the right to create new folders.", "Nemate pravo da pravite nove foldere");
regGS("A file or folder having the name $1 already exists", "Fajl ili folder sa imenom $1 već postoji");
regGS("You do not have the right to delete templates.", "Nemate pravo da brišete šablone");
regGS("Are you sure you want to delete the folder $1 from $2?", "Da li ste sigurni da želite da obrišete folder $1 iz $2?");
regGS("Are you sure you want to delete the template $1 from folder $2?", "Da li ste sigurni da želite da obrišete šablon $1 iz foldera $2?");
regGS("Template $1 was deleted", "Šablon $1 je obrisan");
regGS("Delete folder", "Obriši folder");
regGS("Folders", "Folderi");
regGS("No folders.", "Nema foldera.");
regGS("Files", "Fajlovi");
regGS("No templates.", "Nema šablona.");
regGS("File", "Fajl");
regGS("Create new template", "Napravi novi šablon");
regGS("Duplicate template", "Dupliraj šablon");
regGS("Edit template", "Uredi šablon");
regGS("The template $1 could not be created.", "Šablon $1 ne može biti napravljen.");
regGS("Template $1 was changed", "Šablon $1 je promenjen");
regGS("Template $1 was duplicated into $2", "Šablon $1 je dupliran u $2");
regGS("Template charset", "Kodni raspored šablona");
regGS("Select a language/character set", "Izaberi jezik/kodni raspored");
regGS("All languages", "Svi jezici");
regGS("You do not have the right to modify templates.", "Nemate pravo da menjate šablone.");
regGS("Invalid template file $1", "Pogrešno ime šablona $1");
regGS("You do not have the right to create folders.", "Nemate pravo da pravite foldere.");
regGS("You do not have the right to upload templates.", "Nemate pravo da aploudujete šablone.");
regGS("You do not have the right to create templates.", "Nemate pravo da pravite šablone.");
regGS("Duplicate file", "Dupliraj fajl");
regGS("Delete file", "Obriši fajl");
regGS("Please check if the user '$1' has permission to write in this directory.", "Proverite da li korisnik '$1' ima ovlašćenja da upisuje u ovoaj direktorijum.");
regGS("The folder has been deleted.", "Folder je izbrisan");
regGS("The template has been deleted.", "Šablon je izbrisan");
regGS("The template could not be deleted.", "Šablon ne može biti izbrisan");
regGS("Save", "Snimi");
?>
